import { useState, useEffect } from 'react';
import { API, graphqlOperation } from 'aws-amplify';
import { onUpdateFacility } from '../graphql/subscriptions';
import { OnUpdateFacilitySubscription, RecordingStatus } from '../API';

type Result = {
  value: {
    data: OnUpdateFacilitySubscription;
  };
};

type Facility = OnUpdateFacilitySubscription['onUpdateFacility'];

const useSubscribeFacility = () => {
  const [facility, setFacility] = useState<Facility>({
    __typename: 'Facility',
    id: '',
    name: '',
    numberOfPeople: 0,
    description: '',
    recordingStatus: RecordingStatus.INACTIVE
  });
  useEffect(() => {
    // 施設情報の更新をSubscribe
    const subscription = API.graphql(
      graphqlOperation(onUpdateFacility)
    ).subscribe({
      next: (result: Result) => {
        setFacility(result.value.data.onUpdateFacility);
      }
    });

    return () => {
      subscription.unsubscribe();
    };
  }, []);

  return { facility };
};
export default useSubscribeFacility;
